@@ -10,7 +10,7 @@ use Symbol;
 
 use vars qw($VERSION $AUTOLOAD);
 
-$VERSION = '0.09';
+$VERSION = '0.10';
 
 my ($yaml_loader, $yaml_dumper);
 
@@ -460,8 +460,7 @@ sub find_yaml_code {
     for my $pkg (@yaml_packages) {
         (my $path = $pkg) =~ s/::/\//g;
         $path .= '.pm';
-        return $pkg if exists $INC{$path};
-        eval "require $pkg; 1" or next;
+        eval "require $pkg; 1" or next if !$INC{$path};
         my $L = $pkg->can('Load') or next;
         my $D = $pkg->can('Dump') or next;
         return ($L, $D);
